import { httpApp } from "@/plugins/axiosApp";

/** 用户分页查询 */
export function getUserList(params: {
  loginName?: string;
  name?: string;
  enable?: boolean;
  roleId: number;
  rootOrgId: number;
  pageNo?: number;
  pageSize?: number;
}) {
  return httpApp.post("/api/ess/user/page", params);
}

/** 更新用户 */
export function updateUser(params: {
  loginName?: string;
  password?: string;
  enable?: boolean;
  id?: number;
  roleId?: number;
  name?: string;
  rootOrgId?: number;
}) {
  return httpApp.post("/api/ess/user/save", params);
}

/** 禁用、启用用户 */
export function toggleUsers(enable: boolean, ids: number[]) {
  return httpApp.post(
    `/api/ess/user/${enable ? "enable" : "disable"}`,
    new URLSearchParams([["ids", ids.join(",")]])
  );
}

/** 删除用户 */
export function resetPasswords(ids: number[]) {
  return httpApp.post(
    `/api/ess/user/password`,
    new URLSearchParams([["password", ids.join(",")]])
  );
}

/** 导入用户 */
export function importUsers(rootOrgId: number, file: File) {
  const f = new FormData();
  f.append("rootOrgId", rootOrgId + "");
  f.append("file", file);
  return httpApp.post(`/api/ess/user/import`, f);
}

/** 导出用户 */
export function exportUsers(params: {
  rootOrgId: number;
  roleId?: number;
  loginName?: string;
  name?: string;
  enable?: boolean;
}) {
  return httpApp.post(`/api/ess/user/export`, params);
}
